=== modified file 'loggerhead/templatefunctions.py'
--- loggerhead/templatefunctions.py	2011-03-23 02:37:07 +0000
+++ loggerhead/templatefunctions.py	2011-03-23 04:04:44 +0000
@@ -23,7 +23,7 @@
 
 import loggerhead
 from loggerhead.zptsupport import zpt
-from loggerhead.util import html_escape
+from loggerhead.util import html_format
 
 
 templatefunctions = {}
@@ -50,20 +50,21 @@
     if style == 'fragment':
         def file_link(filename):
             if currently_showing and filename == currently_showing:
-                return '<b><a href="#%s">%s</a></b>' % (
-                    urllib.quote(filename.encode('utf-8')),
-                    html_escape(filename))
+                return html_format(
+                    '<b><a href="#%s">%s</a></b>',
+                    urllib.quote(filename.encode('utf-8')), filename)
             else:
                 return revision_link(
                     url, entry.revno, filename,
                     '#' + urllib.quote(filename.encode('utf-8')))
     else:
         def file_link(filename):
-            return '<a href="%s%s" title="View changes to %s in revision %s">%s</a>' % (
+            return html_format(
+                '<a href="%s%s" title="View changes to %s in revision %s">'
+                '%s</a>',
                 url(['/revision', entry.revno]),
                 '#' + urllib.quote(filename.encode('utf-8')),
-                html_escape(filename), html_escape(entry.revno),
-                html_escape(filename))
+                filename, entry.revno, filename)
     return _pt('revisionfilechanges').expand(
         entry=entry, file_changes=file_changes, file_link=file_link, **templatefunctions)
 
@@ -127,15 +128,16 @@
 
 @templatefunc
 def view_link(url, revno, path):
-    return '<a href="%s" title="Annotate %s">%s</a>' % (
-        url(['/view', revno, path]), html_escape(path), html_escape(path))
+    return html_format(
+        '<a href="%s" title="Annotate %s">%s</a>',
+        url(['/view', revno, path]), path, path)
 
 
 @templatefunc
 def revision_link(url, revno, path, frag=''):
-    return '<a href="%s%s" title="View changes to %s in revision %s">%s</a>' % (
-        url(['/revision', revno, path]), frag, html_escape(path),
-        html_escape(revno), html_escape(path))
+    return html_format(
+        '<a href="%s%s" title="View changes to %s in revision %s">%s</a>',
+        url(['/revision', revno, path]), frag, path, revno, path)
 
 
 @templatefunc

=== modified file 'loggerhead/util.py'
--- loggerhead/util.py	2011-03-23 03:59:38 +0000
+++ loggerhead/util.py	2011-03-23 04:04:44 +0000
@@ -227,12 +227,18 @@
 
     Like cgi.escape, except also escaping " and '. This makes it safe to use
     in both attribute and element content.
+
+    If you want to safely fill a format string with escaped values, use
+    html_format instead
     """
     return "".join(html_entity_map.get(c, c) for c in s)
 
 
 def html_format(template, *args):
-    """Safely format an HTML template string, escaping the arguments."""
+    """Safely format an HTML template string, escaping the arguments.
+
+    The template string must not be user-controlled; it will not be escaped.
+    """
     return template % tuple(html_escape(arg) for arg in args)
 
 

